@@ -18,6 +18,8 @@
 #'
 #' @param background_color string, a valid ImageMagick color string such as "white" or "#000080". The color to use when extending images (e.g., when creating the border).
 #'
+#' @return vector of character strings, paths to the brainview images. This is the input parameter 'brainview_images'.
+#'
 #' @export
 arrange.brainview.images <- function(brainview_images, output_img, colorbar_img=NULL, silent=FALSE, grid_like=TRUE, border_geometry="5x5", background_color = "white") {
 
@@ -78,6 +80,7 @@ arrange.brainview.images <- function(brainview_images, output_img, colorbar_img=
         warning("The 'magick' package must be installed to use this functionality. Merged image NOT written.");
     }
 
+    return(invisible(brainview_images));
 }
 
 
