@@ -721,3 +721,17 @@ find.freesurferhome <- function(mustWork=FALSE) {
 
   return(ret);
 }
+
+
+#' @title Get rgl_options for testing.
+#'
+#' @description This function defines the figure size that is used during the unit tests.
+#'
+#' @return named list, usable as 'rgl_options' parameter for vis functions like \code{\link[fsbrain]{vis.subject.morph.native}}.
+#'
+#' @note This function is public so one can copy and paste unit test code into the R console, but you should not consider it part of the official functions and use it in your client code.
+#'
+#' @export
+rglot <- function() {
+    return(list('windowRect' = c(50, 50, 800, 800)));
+}
